@@ -51,6 +51,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 
 	switch (fxt) {
 	case FX_ARPEGGIO:
+	      fx_arpeggio:
 		if (fxp != 0) {
 			xc->arpeggio.val[0] = 0;
 			xc->arpeggio.val[1] = MSN(fxp);
@@ -58,6 +59,13 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			xc->arpeggio.size = 3;
 		}
 		break;
+	case FX_S3M_ARPEGGIO:
+		if (fxp == 0) {
+			fxp = xc->arpeggio.memory;
+		} else {
+			xc->arpeggio.memory = fxp;
+		}
+		goto fx_arpeggio;
 	case FX_OKT_ARP3:
 		if (fxp != 0) {
 			xc->arpeggio.val[0] = -MSN(fxp);
@@ -427,7 +435,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			if (fxp != 0) {
 				xc->retrig.val = fxp;
 			}
-			xc->retrig.count = LSN(xc->retrig.val);
+			xc->retrig.count = LSN(xc->retrig.val) + 1;
 			xc->retrig.type = 0;
 			break;
 		case EX_F_VSLIDE_UP:	/* Fine volume slide up */
@@ -718,18 +726,16 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 	case FX_FLT_RESN:
 		xc->filter.resonance = fxp;
 		break;
-	case FX_CHORUS:
 #if 0
+	case FX_CHORUS:
 		/* FIXME */
 		m->mod.xxc[chn].cho = fxp;
-#endif
 		break;
 	case FX_REVERB:
-#if 0
 		/* FIXME */
 		m->mod.xxc[chn].rvb = fxp;
-#endif
 		break;
+#endif
 	case FX_NSLIDE_DN:
 	case FX_NSLIDE_UP:
 	case FX_NSLIDE_R_DN:
