@@ -123,7 +123,7 @@ static const uint8 fx[] =
 	FX_TONEPORTA,		/* Gxx  Tone portamento with speed xx */
 	FX_VIBRATO,		/* Hxy  Vibrato with speed x and depth y */
 	FX_TREMOR,		/* Ixy  Tremor with ontime x and offtime y */
-	FX_ARPEGGIO,		/* Jxy  Arpeggio with halfnote additions */
+	FX_S3M_ARPEGGIO,	/* Jxy  Arpeggio with halfnote additions */
 	FX_VIBRA_VSLIDE,	/* Kxy  Dual command: H00 and Dxy */
 	FX_TONE_VSLIDE,		/* Lxy  Dual command: G00 and Dxy */
 	NONE,
@@ -144,17 +144,11 @@ static const uint8 fx[] =
 
 
 /* Effect translation */
-static void xlat_fx(int c, struct xmp_event *e, uint8 *arpeggio_val)
+static void xlat_fx(int c, struct xmp_event *e)
 {
     uint8 h = MSN (e->fxp), l = LSN (e->fxp);
 
     switch (e->fxt = fx[e->fxt]) {
-    case FX_ARPEGGIO:			/* Arpeggio */
-	if (e->fxp)
-	    arpeggio_val[c] = e->fxp;
-	else
-	    e->fxp = arpeggio_val[c];
-	break;
     case FX_S3M_EXTENDED:		/* Extended effects */
 	e->fxt = FX_EXTENDED;
 	switch (h) {
@@ -210,7 +204,6 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
     int quirk87 = 0;
     uint16 *pp_ins;		/* Parapointers to instruments */
     uint16 *pp_pat;		/* Parapointers to patterns */
-    uint8 arpeggio_val[32];
     int ret;
 
     LOAD_INIT();
@@ -378,11 +371,9 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
     D_(D_INFO "Stored patterns: %d", mod->pat);
 
-    memset (arpeggio_val, 0, 32);
-
     for (i = 0; i < mod->pat; i++) {
 	if (pattern_tracks_alloc(mod, i, 64) < 0)
-		return -1;
+	    goto err3;
 
 	if (pp_pat[i] == 0)
 	    continue;
@@ -426,7 +417,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	    if (b & S3M_FX_FOLLOWS) {
 		event->fxt = hio_read8(f);
 		event->fxp = hio_read8(f);
-		xlat_fx(c, event, arpeggio_val);
+		xlat_fx(c, event);
 		pat_len -= 2;
 	    }
 	}
@@ -436,21 +427,27 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
     D_(D_INFO "Pan settings: %s", sfh.dp ? "no" : "yes");
 
     if (instrument_init(mod) < 0)
-	return -1;
+	goto err3;
 
     /* Read and convert instruments and samples */
 
     D_(D_INFO "Instruments: %d", mod->ins);
 
     for (i = 0; i < mod->ins; i++) {
-	mod->xxi[i].sub = calloc(sizeof (struct xmp_subinstrument), 1);
-	if (mod->xxi[i].sub == NULL)
-	    return -1;
+	struct xmp_instrument *xxi = &mod->xxi[i];
+	struct xmp_sample *xxs = &mod->xxs[i];
+	struct xmp_subinstrument *sub;
+
+	xxi->sub = calloc(sizeof (struct xmp_subinstrument), 1);
+	if (xxi->sub == NULL)
+	    goto err3;
+
+	sub = &xxi->sub[0];
 
 	hio_seek(f, start + pp_ins[i] * 16, SEEK_SET);
 	x8 = hio_read8(f);
-	mod->xxi[i].sub[0].pan = 0x80;
-	mod->xxi[i].sub[0].sid = i;
+	sub->pan = 0x80;
+	sub->sid = i;
 
 	if (x8 >= 2) {
 	    /* OPL2 FM instrument */
@@ -469,22 +466,21 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
 	    if (sah.magic != MAGIC_SCRI) {
 		D_(D_CRIT "error: FM instrument magic");
-		goto err;
+		goto err3;
 	    }
 	    sah.magic = 0;
 
 	    instrument_name(mod, i, sah.name, 28);
 
-	    mod->xxi[i].nsm = 1;
-	    mod->xxi[i].sub[0].vol = sah.vol;
-	    c2spd_to_note(sah.c2spd, &mod->xxi[i].sub[0].xpo, &mod->xxi[i].sub[0].fin);
-	    mod->xxi[i].sub[0].xpo += 12;
-	    ret = load_sample(m, f, SAMPLE_FLAG_ADLIB, &mod->xxs[i],
-							(char *)&sah.reg);
+	    xxi->nsm = 1;
+	    sub->vol = sah.vol;
+	    c2spd_to_note(sah.c2spd, &sub->xpo, &sub->fin);
+	    sub->xpo += 12;
+	    ret = load_sample(m, f, SAMPLE_FLAG_ADLIB, xxs, (char *)&sah.reg);
 	    if (ret < 0)
-		return -1;
+		goto err3;
 
-	    D_(D_INFO "[%2X] %-28.28s", i, mod->xxi[i].name);
+	    D_(D_INFO "[%2X] %-28.28s", i, xxi->name);
 
 	    continue;
 	}
@@ -519,37 +515,36 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	    fix87(sih.flags);
 	}
 
-	mod->xxs[i].len = sih.length;
-	mod->xxi[i].nsm = sih.length > 0 ? 1 : 0;
-	mod->xxs[i].lps = sih.loopbeg;
-	mod->xxs[i].lpe = sih.loopend;
+	xxs->len = sih.length;
+	xxi->nsm = sih.length > 0 ? 1 : 0;
+	xxs->lps = sih.loopbeg;
+	xxs->lpe = sih.loopend;
 
-	mod->xxs[i].flg = sih.flags & 1 ? XMP_SAMPLE_LOOP : 0;
+	xxs->flg = sih.flags & 1 ? XMP_SAMPLE_LOOP : 0;
 
 	if (sih.flags & 4) {
-	    mod->xxs[i].flg |= XMP_SAMPLE_16BIT;
+	    xxs->flg |= XMP_SAMPLE_16BIT;
 	}
 
-	mod->xxi[i].sub[0].vol = sih.vol;
+	sub->vol = sih.vol;
 	sih.magic = 0;
 
 	instrument_name(mod, i, sih.name, 28);
 
 	D_(D_INFO "[%2X] %-28.28s %04x%c%04x %04x %c V%02x %5d",
 			i, mod->xxi[i].name, mod->xxs[i].len,
-			mod->xxs[i].flg & XMP_SAMPLE_16BIT ?'+' : ' ',
-			mod->xxs[i].lps, mod->xxs[i].lpe,
-			mod->xxs[i].flg & XMP_SAMPLE_LOOP ?  'L' : ' ',
-			mod->xxi[i].sub[0].vol, sih.c2spd);
+			xxs->flg & XMP_SAMPLE_16BIT ?'+' : ' ',
+			xxs->lps, mod->xxs[i].lpe,
+			xxs->flg & XMP_SAMPLE_LOOP ?  'L' : ' ',
+			sub->vol, sih.c2spd);
 
-	c2spd_to_note(sih.c2spd, &mod->xxi[i].sub[0].xpo, &mod->xxi[i].sub[0].fin);
+	c2spd_to_note(sih.c2spd, &sub->xpo, &sub->fin);
 
 	hio_seek(f, start + 16L * sih.memseg, SEEK_SET);
 
-	ret = load_sample(m, f, (sfh.ffi - 1) * SAMPLE_FLAG_UNS,
-						&mod->xxs[i], NULL);
+	ret = load_sample(m, f, (sfh.ffi - 1) * SAMPLE_FLAG_UNS, xxs, NULL);
 	if (ret < 0)
-		return -1;
+		goto err3;
     }
 
     free(pp_pat);
