@@ -127,6 +127,7 @@ static int check_delay(struct context_data *ctx, struct xmp_event *e, int chn)
 {
 	struct player_data *p = &ctx->p;
 	struct channel_data *xc = &p->xc_data[chn];
+	struct module_data *m = &ctx->m;
 
 	/* Tempo affects delay and must be computed first */
 	if ((e->fxt == FX_SPEED && e->fxp < 0x20) || e->fxt == FX_S3M_SPEED) {
@@ -140,23 +141,32 @@ static int check_delay(struct context_data *ctx, struct xmp_event *e, int chn)
 		}
 	}
 
-	/* Delay the entire fetch cycle */
-	if (e->fxt == FX_EXTENDED && MSN(e->fxp) == EX_DELAY) {
+	/* Delay event read */
+	if (e->fxt == FX_EXTENDED && MSN(e->fxp) == EX_DELAY && LSN(e->fxp)) {
 		xc->delay = LSN(e->fxp) + 1;
-		xc->delayed_event = e;
-		if (e->ins)
-			xc->delayed_ins = e->ins;
-		return 1;
+		goto do_delay;
 	}
-	if (e->f2t == FX_EXTENDED && MSN(e->f2p) == EX_DELAY) {
+	if (e->f2t == FX_EXTENDED && MSN(e->f2p) == EX_DELAY && LSN(e->f2p)) {
 		xc->delay = LSN(e->f2p) + 1;
-		xc->delayed_event = e;
-		if (e->ins)
-			xc->delayed_ins = e->ins;
-		return 1;
+		goto do_delay;
 	}
 
 	return 0;
+
+    do_delay:
+	memcpy(&xc->delayed_event, e, sizeof (struct xmp_event));
+
+	if (e->ins)
+		xc->delayed_ins = e->ins;
+
+	if (HAS_QUIRK(QUIRK_RTDELAY)) {
+		if (e->note == 0)
+			xc->delayed_event.note = xc->key + 1;
+		if (e->ins == 0)
+			xc->delayed_event.ins = xc->ins + 1;
+	}
+
+	return 1;
 }
 
 static inline void read_row(struct context_data *ctx, int pat, int row)
@@ -649,7 +659,7 @@ static void play_channel(struct context_data *ctx, int chn, int t)
 	/* Do delay */
 	if (xc->delay > 0) {
 		if (--xc->delay == 0) {
-			read_event(ctx, xc->delayed_event, chn);
+			read_event(ctx, &xc->delayed_event, chn);
 		}
 	}
 
