@@ -97,6 +97,7 @@ struct channel_data {
         	int8 val[16];	/* 16 for Smaksak MegaArps */
 		int size;
 		int count;
+		int memory;
 	} arpeggio;
 
 	struct {
@@ -175,7 +176,7 @@ struct channel_data {
 
 	void *extra;
 
-	struct xmp_event *delayed_event;
+	struct xmp_event delayed_event;
 	int delayed_ins;	/* IT save instrument emulation */
 
 	int info_period;	/* Period */
