@@ -353,7 +353,10 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 	if ((uint32)key <= XMP_MAX_KEYS && key > 0) {
 		xc->key = --key;
 		xc->fadeout = 0x10000;
-		RESET_NOTE(NOTE_RELEASE | NOTE_END);
+		RESET_NOTE(NOTE_END);
+		if (~mod->xxi[xc->ins].aei.flg & XMP_ENVELOPE_ON) {
+			RESET_NOTE(NOTE_RELEASE);
+		}
 
 		sub = get_subinstrument(ctx, xc->ins, key);
 
@@ -802,7 +805,6 @@ static int read_event_smix(struct context_data *ctx, struct xmp_event *e, int ch
 	int ins, note, transp, smp;
 
 	xc->flags = 0;
-	note = -1;
 
 	if (!e->ins)
 		return 0;
